@@ -1,5 +1,5 @@
 /*
-** Copyright 2003-2004 Double Precision, Inc.
+** Copyright 2003-2011 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -66,7 +66,6 @@
 
 #define SMAP_BUFSIZ 8192
 
-static const char rcsid[]="$Id: smap.c,v 1.28 2009/09/05 11:59:26 mrsam Exp $";
 #define SHARED "shared"
 
 #define LIST_FOLDER 1
@@ -1474,6 +1473,7 @@ static int dump_hdrs(int fd, unsigned long n,
 		     struct rfc2045 *rfcp, const char *hdrs,
 		     const char *type)
 {
+	struct rfc2045src *src;
 	struct rfc2045headerinfo *h;
 	char *header;
 	char *value;
@@ -1529,7 +1529,8 @@ static int dump_hdrs(int fd, unsigned long n,
 		writes("\"\n");
 	}
 
-	h=rfc2045header_start(fd, rfcp);
+	src=rfc2045src_init_fd(fd);
+	h=src ? rfc2045header_start(src, rfcp):NULL;
  
 	while (h &&
 	       (rc=rfc2045header_get(h, &header, &value, get_flags)) == 0
@@ -1553,7 +1554,8 @@ static int dump_hdrs(int fd, unsigned long n,
 		rfc2045header_end(h);
 	else
 		rc= -1;
-
+	if (src)
+		rfc2045src_deinit(src);
 	return rc;
 }
 
@@ -1695,6 +1697,7 @@ static int dump_decoded(FILE *fp, unsigned long msgNum,
 	const char *charset;
         off_t start_pos, end_pos, dummy, start_body;
 
+	struct rfc2045src *src;
 	struct rfc2045 *myrfcp=NULL;
 	int fd;
 	int i;
@@ -1737,9 +1740,16 @@ static int dump_decoded(FILE *fp, unsigned long msgNum,
 		/* Better estimate of base64 content */
 	}
 
-	i=rfc2045_decodemimesection(fd, rfcp, &do_dump_decoded, &myDecodeInfo);
+	src=rfc2045src_init_fd(fd);
+
+	i=src ? rfc2045_decodemimesection(src, rfcp, &do_dump_decoded,
+					  &myDecodeInfo):-1;
+
 	do_dump_decoded_flush(&myDecodeInfo);
 
+	if (src)
+		rfc2045src_deinit(src);
+
 	close(fd);
 
 	if (i == 0 && myDecodeInfo.first) /* Empty body, punt */
@@ -4524,7 +4534,7 @@ void smap()
 			searchResults.prev_search_hit=0;
 			searchResults.prev_search_hit_start=0;
 
-			search_internal(si, searchInfo, &unicode_UTF8, 0,
+			search_internal(si, searchInfo, "utf-8", 0,
 					smap1_search_cb, &searchResults);
 
 			if (searchResults.prev_search_hit)
