@@ -1,9 +1,8 @@
 /*
-** Copyright 2001-2009 Double Precision, Inc.  See COPYING for
+** Copyright 2001-2011 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
-static const char rcsid[]="$Id: pcp.c,v 1.10 2009/11/08 18:14:47 mrsam Exp $";
 
 #include "config.h"
 #include <stdio.h>
@@ -1313,22 +1312,29 @@ static int list_msg_textplain(struct rfc2045 *rfc, FILE *fp)
 {
 	const char *mime_charset, *dummy;
 	int rc;
+	struct rfc2045src *src;
 
         rfc2045_mimeinfo(rfc, &dummy, &dummy, &mime_charset);
 
-        if (strcasecmp(mime_charset, charset) &&
-            strcasecmp(mime_charset, "us-ascii"))
+        if (strcasecmp(mime_charset, charset))
         {
-		printf(gettext("    (%s charset follows)\n\n"),
+		printf(gettext("    (The following text was converted from %s)\n\n"),
 		       mime_charset);
 	}
 
-	rc=rfc2045_decodetextmimesection(fileno(fp),
+	src=rfc2045src_init_fd(fileno(fp));
+
+	if (src == NULL)
+		return (-1);
+
+	rc=rfc2045_decodetextmimesection(src,
 					 rfc,
 					 charset,
+					 NULL,
 					 textplain_output, NULL);
 
 	printf("\n");
+	rfc2045src_deinit(src);
 	return (rc);
 }
 
@@ -1368,6 +1374,7 @@ static void douncancel(const char *id, int flags)
 	struct PCP *pcp=open_calendar();
 	struct PCP_uncancel uncancel_info;
 
+	memset(&uncancel_info, 0, sizeof(uncancel_info));
 	uncancel_info.uncancel_conflict_callback= &show_conflict;
 	uncancel_info.uncancel_conflict_callback_ptr=NULL;
 
@@ -1631,16 +1638,7 @@ static void doconnectwrite(int fd, const char *p, int cnt)
 
 static void usage()
 {
-	const char *charset=RFC2045CHARSET;
-
-	{
-		const char *p=nl_langinfo(CODESET);
-
-		if (unicode_find(p) != NULL)
-			charset=p;
-
-	}
-
+	const char *charset=unicode_default_chset();
 
 	fprintf(stderr,
 		gettext("Usage: pcp [options] [command]\n"
@@ -1721,13 +1719,7 @@ int main(int argc, char **argv)
 	setlocale(LC_ALL, "");
 	textdomain("pcp");
 
-	{
-		const char *p=nl_langinfo(CODESET);
-
-		if (unicode_find(p) != NULL)
-			charset=p;
-
-	}
+	charset=unicode_default_chset();
 
 	while ((optchar=getopt(argc, argv, "emcs:C:")) >= 0)
 	{
